==> zio-aws-emr_2.12-5.17.112.1-sources.jar: zio/aws/emr/model/ScalingAction.scala <==
package zio.aws.emr.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ScalingAction(
    market: Option[zio.aws.emr.model.MarketType] = None,
    simpleScalingPolicyConfiguration: zio.aws.emr.model.SimpleScalingPolicyConfiguration
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.emr.model.ScalingAction = {
    import ScalingAction.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.ScalingAction
      .builder()
      .optionallyWith(market.map(value => value.unwrap))(_.market)
      .simpleScalingPolicyConfiguration(
        simpleScalingPolicyConfiguration.buildAwsValue()
      )
      .build()
  }
  def asReadOnly: zio.aws.emr.model.ScalingAction.ReadOnly =
    zio.aws.emr.model.ScalingAction.wrap(buildAwsValue())
}
object ScalingAction {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.emr.model.ScalingAction] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.ScalingAction =
      zio.aws.emr.model.ScalingAction(
        market.map(value => value),
        simpleScalingPolicyConfiguration.asEditable
      )
    def market: Option[zio.aws.emr.model.MarketType]
    def simpleScalingPolicyConfiguration
        : zio.aws.emr.model.SimpleScalingPolicyConfiguration.ReadOnly
    def getMarket: ZIO[Any, AwsError, zio.aws.emr.model.MarketType] =
      AwsError.unwrapOptionField("market", market)
    def getSimpleScalingPolicyConfiguration: ZIO[
      Any,
      Nothing,
      zio.aws.emr.model.SimpleScalingPolicyConfiguration.ReadOnly
    ] = ZIO.succeed(simpleScalingPolicyConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.ScalingAction
  ) extends zio.aws.emr.model.ScalingAction.ReadOnly {
    override val market: Option[zio.aws.emr.model.MarketType] = scala
      .Option(impl.market())
      .map(value => zio.aws.emr.model.MarketType.wrap(value))
    override val simpleScalingPolicyConfiguration
        : zio.aws.emr.model.SimpleScalingPolicyConfiguration.ReadOnly =
      zio.aws.emr.model.SimpleScalingPolicyConfiguration
        .wrap(impl.simpleScalingPolicyConfiguration())
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.ScalingAction
  ): zio.aws.emr.model.ScalingAction.ReadOnly = new Wrapper(impl)
}

==> zio-aws-emr_2.13-7.28.24.2-sources.jar: zio/aws/emr/model/ScalingAction.scala <==
package zio.aws.emr.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ScalingAction(
    market: Optional[zio.aws.emr.model.MarketType] = Optional.Absent,
    simpleScalingPolicyConfiguration: zio.aws.emr.model.SimpleScalingPolicyConfiguration
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.emr.model.ScalingAction = {
    import ScalingAction.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.ScalingAction
      .builder()
      .optionallyWith(market.map(value => value.unwrap))(_.market)
      .simpleScalingPolicyConfiguration(
        simpleScalingPolicyConfiguration.buildAwsValue()
      )
      .build()
  }
  def asReadOnly: zio.aws.emr.model.ScalingAction.ReadOnly =
    zio.aws.emr.model.ScalingAction.wrap(buildAwsValue())
}
object ScalingAction {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.emr.model.ScalingAction] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.ScalingAction =
      zio.aws.emr.model.ScalingAction(
        market.map(value => value),
        simpleScalingPolicyConfiguration.asEditable
      )
    def market: Optional[zio.aws.emr.model.MarketType]
    def simpleScalingPolicyConfiguration
        : zio.aws.emr.model.SimpleScalingPolicyConfiguration.ReadOnly
    def getMarket: ZIO[Any, AwsError, zio.aws.emr.model.MarketType] =
      AwsError.unwrapOptionField("market", market)
    def getSimpleScalingPolicyConfiguration: ZIO[
      Any,
      Nothing,
      zio.aws.emr.model.SimpleScalingPolicyConfiguration.ReadOnly
    ] = ZIO.succeed(simpleScalingPolicyConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.ScalingAction
  ) extends zio.aws.emr.model.ScalingAction.ReadOnly {
    override val market: Optional[zio.aws.emr.model.MarketType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.market())
        .map(value => zio.aws.emr.model.MarketType.wrap(value))
    override val simpleScalingPolicyConfiguration
        : zio.aws.emr.model.SimpleScalingPolicyConfiguration.ReadOnly =
      zio.aws.emr.model.SimpleScalingPolicyConfiguration
        .wrap(impl.simpleScalingPolicyConfiguration())
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.ScalingAction
  ): zio.aws.emr.model.ScalingAction.ReadOnly = new Wrapper(impl)
}
